# DBGear

## 特徴

- データベースの初期データの管理を行います。
- データ編集用のUIが用意されており、簡単にデータの編集が行えます。
- テーブル定義の内容は初期データへにも反映され、データの編集を容易にします。
- 関連データも定義することが可能で、IDのコピペなどを行う必要がありません。
- ユニットテストなどとの連携も行い、より整合性の高いテストを実施できます。
- 保存データはYAML形式で保存されており、Gitなどのバージョン管理、差分管理が可能です。

## インストール

```bash
pip install dbgear
```

## プロジェクトファイルの準備

（準備中）

## 実行

- 以下のコマンドで管理ツールが起動できます。

```
dbgear serve
```

- ブラウザで http://localhost:5000 にアクセスすると管理画面が表示されます。
